<?php
/**
 * Custom functions that act independently of the theme templates
 * Eventually, some of the functionality here could be replaced by core features
 */

/**
 * Adds custom classes to the array of body classes.
 */
function smallbiz_body_classes( $classes ) {

	// Adds a class of multi-author to blogs with more than 1 published author.
	if ( is_multi_author() ) {
		$classes[] = 'multi-author';
	}

	// Adds a class if post or page has featured image.
	if ( has_post_thumbnail() ) {
		$classes[] = 'has-featured-image';
	}

	// Adds a class on Full Width and Grid page.
	if ( is_page_template( 'page-templates/full-width-page.php' ) || is_page_template( 'page-templates/grid-page.php' ) ) {
		$classes[] = 'full-width-page';
	}

	// Adds a class on Full Width Narrow page.
	if ( is_page_template( 'page-templates/full-width-narrow-page.php' ) ) {
		$classes[] = 'full-width-narrow-page';
	}

	// Adds a class for container style.
	$container = get_theme_mod( 'smallbiz_container_style', 'fullwidth' );
	if ( $container === 'fullwidth' ) {
		$classes[] = 'container-fullwidth';
	} elseif ( $container === 'boxed' ) {
		$classes[] = 'container-boxed';
	} else {
		$classes[] = 'container-framed';
	}

	return $classes;
}
add_filter( 'body_class', 'smallbiz_body_classes' );

/**
 * Adds custom classes to the array of post classes.
 */
function smallbiz_post_classes( $classes ) {

	// Adds a class if a post hasn't a thumbnail.
	if ( ! has_post_thumbnail() ) {
		$classes[] = 'no-post-thumbnail';
	}

	// Replace hentry class with entry.
	$classes[] = 'entry';

	return $classes;
}
add_filter( 'post_class', 'smallbiz_post_classes' );

/**
 * Remove 'hentry' from post_class()
 */
function smallbiz_remove_hentry( $class ) {
	$class = array_diff( $class, array( 'hentry' ) );
	return $class;
}
add_filter( 'post_class', 'smallbiz_remove_hentry' );

/**
 * Change the excerpt more string.
 */
function smallbiz_excerpt_more( $more ) {
	return '&hellip;';
}
add_filter( 'excerpt_more', 'smallbiz_excerpt_more' );

/**
 * Register custom contact info fields.
 */
function smallbiz_contact_info_fields( $contactmethods ) {
	$contactmethods['twitter']     = esc_html__( 'Twitter URL', 'smallbiz' );
	$contactmethods['facebook']    = esc_html__( 'Facebook URL', 'smallbiz' );
	$contactmethods['gplus']       = esc_html__( 'Google Plus URL', 'smallbiz' );
	$contactmethods['instagram']   = esc_html__( 'Instagram URL', 'smallbiz' );
	$contactmethods['pinterest']   = esc_html__( 'Pinterest URL', 'smallbiz' );
	$contactmethods['linkedin']    = esc_html__( 'Linkedin URL', 'smallbiz' );

	// Remove default contacts
	unset( $contactmethods['aim'] );
	unset( $contactmethods['jabber'] );
	unset( $contactmethods['yim'] );

	return $contactmethods;
}
add_filter( 'user_contactmethods', 'smallbiz_contact_info_fields' );

/**
 * Extend archive title
 */
function smallbiz_extend_archive_title( $title ) {
	if ( is_category() ) {
		$title = single_cat_title( '', false );
	} elseif ( is_tag() ) {
		$title = single_tag_title( '', false );
	} elseif ( is_author() ) {
		$title = get_the_author();
	}
	return $title;
}
add_filter( 'get_the_archive_title', 'smallbiz_extend_archive_title' );

/**
 * Customize tag cloud widget
 */
function smallbiz_customize_tag_cloud( $args ) {
	$args['largest']  = 13;
	$args['smallest'] = 13;
	$args['unit']     = 'px';
	$args['number']   = 20;
	return $args;
}
add_filter( 'widget_tag_cloud_args', 'smallbiz_customize_tag_cloud' );
